DROP CAST (regtype AS text);
DROP FUNCTION regtypetext(regtype);
DROP OPERATOR <> ( name[], name[] );
DROP FUNCTION namearray_ne( name[], name[] );
DROP OPERATOR = ( name[], name[] );
DROP FUNCTION namearray_eq( name[], name[] );
DROP CAST (name[] AS text);
DROP FUNCTION namearray_text(name[]);
DROP CAST (text[] AS text);
DROP FUNCTION textarray_text(text[]);
DROP CAST (boolean AS char(1);
DROP FUNCTION booltext(boolean);
